"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Highlighter = void 0;
var tslib_1 = require("tslib");
var jsx_runtime_1 = require("react/jsx-runtime");
/* eslint-disable react/no-deprecated */
var react_dom_1 = tslib_1.__importDefault(require("react-dom"));
var index_1 = tslib_1.__importDefault(require("html-react-parser/lib/index"));
var addHighlight_1 = require("../../libs/addHighlight");
var serialize_1 = require("../../libs/serialize");
var react_1 = require("react");
var uid_1 = require("../../libs/uid");
var wrapperElements_1 = require("../../libs/wrapperElements");
var DeafultPopover_1 = tslib_1.__importDefault(require("../DeafultPopover"));
var UseSelection_1 = require("../../hooks/UseSelection");
var constants_1 = require("../../constants/constants");
var Highlighter = function (_a) {
    var htmlString = _a.htmlString, onClickHighlight = _a.onClickHighlight, disablePopover = _a.disablePopover, maxSelectionLength = _a.maxSelectionLength, minSelectionLength = _a.minSelectionLength, rootClassName = _a.rootClassName, PopoverChildren = _a.PopoverChildren, PopoverClassName = _a.PopoverClassName, highlightColor = _a.highlightColor, selectionWrapperClassName = _a.selectionWrapperClassName, onClick = _a.onClick;
    var _b = (0, UseSelection_1.useSelections)(), selections = _b.selections, addSelection = _b.addSelection, removeSelection = _b.removeSelection, updateSelection = _b.updateSelection;
    var getWrapper = (0, react_1.useCallback)(function (selection) {
        var backgroundColor = selection.backgroundColor || highlightColor;
        var span = (0, wrapperElements_1.getSpanElement)({ className: selectionWrapperClassName, highlightColor: backgroundColor });
        if (!disablePopover) {
            var popover_1 = (0, wrapperElements_1.getPopoverElement)({ className: PopoverClassName });
            span.addEventListener('mouseover', function () {
                popover_1.style.visibility = 'visible';
                popover_1.style.opacity = '1';
            });
            span.addEventListener('mouseout', function () {
                popover_1.style.visibility = 'hidden';
                popover_1.style.opacity = '0';
            });
            popover_1.id = "pop-".concat(selection.id);
            span.appendChild(popover_1);
            if (PopoverChildren) {
                react_dom_1.default.render((0, jsx_runtime_1.jsx)(PopoverChildren, { selection: selection, removeSelection: removeSelection, updateSelection: updateSelection }), popover_1);
            }
            else {
                react_dom_1.default.render((0, jsx_runtime_1.jsx)(DeafultPopover_1.default, { removeSelection: removeSelection, selection: selection, updateSelection: updateSelection }), popover_1);
            }
        }
        if (onClickHighlight) {
            span.onclick = function (e) { return onClickHighlight(selection, e); };
        }
        span.id = selection.id;
        return span;
    }, [
        selectionWrapperClassName,
        PopoverClassName,
        disablePopover,
        highlightColor,
        onClickHighlight,
        PopoverChildren,
        removeSelection,
        updateSelection,
    ]);
    var handleMouseUp = function () {
        var selection = window.getSelection();
        if (!selection)
            return;
        if (!minSelectionLength) {
            minSelectionLength = constants_1.defaultMinSelectionLength;
        }
        if (minSelectionLength && selection.toString().length < minSelectionLength)
            return;
        if (maxSelectionLength && selection.toString().length > maxSelectionLength)
            return;
        var range = selection.getRangeAt(0);
        if (!(0, addHighlight_1.isHighlightable)(range))
            return;
        var newSelection = {
            meta: (0, serialize_1.serializeRange)(range),
            text: range.toString(),
            id: (0, uid_1.generateId)(),
            backgroundColor: highlightColor || constants_1.defaultColor,
        };
        addSelection(newSelection);
        // addHighlight(range,getWrapper(newSelection))
    };
    (0, react_1.useEffect)(function () {
        if (selections && selections.length) {
            selections.forEach(function (item) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
                var range;
                return tslib_1.__generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, (0, serialize_1.deserializeRange)(item.meta)];
                        case 1:
                            range = _a.sent();
                            if (range) {
                                (0, addHighlight_1.addHighlight)(range, getWrapper(item));
                            }
                            return [2 /*return*/];
                    }
                });
            }); });
        }
    }, [selections, getWrapper]);
    return ((0, jsx_runtime_1.jsx)("div", { onClick: onClick, onMouseUp: handleMouseUp, className: rootClassName, children: (0, index_1.default)(htmlString) }));
};
exports.Highlighter = Highlighter;
