"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSelections = void 0;
var tslib_1 = require("tslib");
var react_1 = require("react");
var SelectionProvider_1 = require("../providers/SelectionProvider");
var removeHighlight_1 = require("../libs/removeHighlight");
var useSelections = function () {
    var selectionContext = (0, react_1.useContext)(SelectionProvider_1.selectionsContext);
    if (!selectionContext) {
        throw new Error('useSelection hook must be used inside selectionProvider');
    }
    var selections = selectionContext.selections, setSelections = selectionContext.setSelections;
    var addSelection = function (selection) {
        setSelections(function (prev) {
            var index = prev.findIndex(function (item) { return item.id === selection.id; });
            if (index === -1) {
                return tslib_1.__spreadArray(tslib_1.__spreadArray([], prev, true), [selection], false);
            }
            return prev;
        });
    };
    var updateSelection = function (id, updatedSelection) {
        setSelections(function (prev) {
            var index = prev.findIndex(function (item) { return item.id === id; });
            if (index !== -1) {
                return prev.splice(index, 1);
            }
            return tslib_1.__spreadArray(tslib_1.__spreadArray([], prev, true), [updatedSelection], false);
        });
    };
    var removeSelection = function (selection) {
        setSelections(function (prev) {
            var index = prev.findIndex(function (item) { return item.id === selection.id; });
            if (index !== -1) {
                (0, removeHighlight_1.removeHighlightFromDom)(selection);
                return prev.splice(index, 1);
            }
            return prev;
        });
    };
    return { selections: selections, setSelections: setSelections, addSelection: addSelection, updateSelection: updateSelection, removeSelection: removeSelection };
};
exports.useSelections = useSelections;
