import { __spreadArray } from "tslib";
import { useContext } from 'react';
import { selectionsContext } from '../providers/SelectionProvider';
import { removeHighlightFromDom } from '../libs/removeHighlight';
export var useSelections = function () {
    var selectionContext = useContext(selectionsContext);
    if (!selectionContext) {
        throw new Error('useSelection hook must be used inside selectionProvider');
    }
    var selections = selectionContext.selections, setSelections = selectionContext.setSelections;
    var addSelection = function (selection) {
        setSelections(function (prev) {
            var index = prev.findIndex(function (item) { return item.id === selection.id; });
            if (index === -1) {
                return __spreadArray(__spreadArray([], prev, true), [selection], false);
            }
            return prev;
        });
    };
    var updateSelection = function (id, updatedSelection) {
        setSelections(function (prev) {
            var index = prev.findIndex(function (item) { return item.id === id; });
            if (index !== -1) {
                return prev.splice(index, 1);
            }
            return __spreadArray(__spreadArray([], prev, true), [updatedSelection], false);
        });
    };
    var removeSelection = function (selection) {
        setSelections(function (prev) {
            var index = prev.findIndex(function (item) { return item.id === selection.id; });
            if (index !== -1) {
                removeHighlightFromDom(selection);
                return prev.splice(index, 1);
            }
            return prev;
        });
    };
    return { selections: selections, setSelections: setSelections, addSelection: addSelection, updateSelection: updateSelection, removeSelection: removeSelection };
};
